@@ -764,7 +764,7 @@ class Stream_Enhancer:
         #print(" cut x=",minX,maxX, "  and y=",minY,maxY )
         cropped = self.frame[minX:maxX, minY:maxY]
         #print("CENTER:",centerX, centerY,"#",  cropped.shape, scale,"x")
-        self.frame = cv2.resize(cropped, (width, height))
+        self.frame = cv2.resize(cropped, (width, height), interpolation=cv2.INTER_NEAREST)
 
 
     def histo(self):
@@ -864,19 +864,21 @@ class Stream_Enhancer:
                 zmqnow = dt.datetime.now()
                 telegramnow = zmqnow
 
+                # telegram
+                if os.path.exists(os.path.expanduser("~/.telegram.token")):
+                    if (telegramnow-self.telegramlast).total_seconds()>300:
+                        y = threading.Thread(target=telegram.bot_send, args=("ALERT", f"CAMERA {self.zmqrpi_name} {zmqnow.strftime('%a %H:%M:%S')}", self.frame))
+                        y.start()
+                        self.telegramlast=telegramnow
 
-                if (telegramnow-self.telegramlast).total_seconds()>300:
-                    y = threading.Thread(target=telegram.bot_send, args=("ALERT", f"CAMERA {self.zmqrpi_name} {zmqnow.strftime('%a %H:%M:%S')}", self.frame))
-                    y.start()
-                    self.telegramlast=telegramnow
-
-
+                # imagezmq
                 if (zmqnow-self.zmqlast).total_seconds()>1.5:
                     x = threading.Thread(target=self.zmqsender.send_image, args=(self.zmqrpi_name, self.frame))
                     x.start()
                     #self.zmqsender.send_image(self.zmqrpi_name, self.frame)
                     self.zmqlast=zmqnow
                     print(f"i... zmq is being sent to {self.zmqtarget}")
+
         # -------------- timelapse if seconds>0:
         elif seconds>0:
             if not self.aviopened_laps:
