@@ -1010,7 +1010,7 @@ Recommendation:
 
                 if save:
                     #savepngcont = False
-                    print("AVI")  # OR MKV now with H264
+                    #print("AVI")  # OR MKV now with H264
                     saviout.write(frame)
                     if senh.add_frame(frame):
                         # print("avi..")
