@@ -209,13 +209,15 @@ class V4L2_CTL():
     def _list_controls(self):
         controls = []
         #print("Executing: " + ' '.join(['v4l2-ctl', '-d', self.device, '-l']))
-        CMD = ['which','v4l2-ctl']
-        child = sp.Popen( CMD, stdout = sp.PIPE )
-        returncode = child.returncode
-        # print(f"i... v4l2-ctl:", returncode, 'str=',child.communicate()[0] )
-        if not(returncode is None):
-            print("X... install v4l2-ctl:  apt install v4l-utils")
-            sys.exit(1)
+        #
+        # ---------- i check in bin_flashcam.py-----------------
+        # CMD = ['which','v4l2-ctl']
+        # child = sp.Popen( CMD, stdout = sp.PIPE )
+        # returncode = child.returncode
+        # # print(f"i... v4l2-ctl:", returncode, 'str=',child.communicate()[0] )
+        # if not(returncode is None):
+        #     print("X... install v4l2-ctl:  apt install v4l-utils")
+        #     sys.exit(1)
 
         CMDL = ['v4l2-ctl', '-d', self.device, '-l']
         #print("i... ", CMDL )
@@ -369,6 +371,7 @@ def set_gem(cc, gain=None, expo=None, mmaga=None):
     if aga!=None: ga,gad,ming,maxg,ga10 = aga  # gain
 
 
+    if not "ex" in locals():  return
 
     print(f"i1... in set_gem: ex={ex}")
     if not expo is None:
@@ -515,7 +518,7 @@ def test_func():
 
 def get_resolutions(vidnum):
     CMD = ['v4l2-ctl', '-d', "/dev/video"+str(vidnum),  "--list-formats-ext"]
-    #print("i... cmd = {CMD}")
+    print(f"i... cmd = {CMD}")
     try:
         output = sp.check_output(CMD).decode(
             "utf-8")  # TODO: Check if the output is valid
