@@ -71,6 +71,8 @@ except:
 app = Flask(__name__)
 
 
+
+
 #==================== ALL config changes must be here ============
 #
 #  1st   'filename'     2nd load config       !!!!!!!!!!!!!!!!!
@@ -696,6 +698,12 @@ def background():
 
 
 
+
+
+#==================== IN FACT == THIS IS THE START OF THE CAMERA =====
+# with asking Camera()    I create an "instance" (static!) of the class
+# and call init_cam
+#
 @app.route('/video')
 @auth.login_required
 def video():
@@ -769,7 +777,9 @@ def gen(camera, remote_ip, blend=False, bigtext=True):
         #     # frame = cv2.add( frame, frame1, mask = frame_mask_inv )
 
         if not(frame is None):  # 95 is default quality
-            frame=cv2.imencode('.jpg', frame, [cv2.IMWRITE_JPEG_QUALITY, 95])[1].tobytes()
+#            frame=cv2.imencode('.jpg', frame, [cv2.IMWRITE_JPEG_QUALITY, 95])[1].tobytes()
+            COMPR = config.CONFIG['kompress']
+            frame=cv2.imencode('.jpg', frame, [cv2.IMWRITE_JPEG_QUALITY, COMPR])[1].tobytes()
         else:
             continue
 
